#Gringotts


Gringotts provides a suite of tools for tracking and planning a user's finances, including models for asset and expense streams, investments, loans, and credit. It is **not** designed to directly manage one's finances by interfacing with financial institutions; rather, through local, user-maintained lists of past and planned transactions and transfers, it provides automated data integration for analytics and projections, to inform the user's decision-making.

Presently, the codebase is a hairball of stable, untested, and incomplete, features with no version control and subpar documentation. However, the core functionality has proven extremely useful to me, and might also be of use to others. Better project management would also simplify the implementation and testing of additional features. Thus, I've begun a project to refactor and package the stable tools for distribution on PyPI (and GitHub), and to initiate a new phase of better-coordinated development.

##Disclaimer
This project was begun for personal use, and I never originally intended to distribute it. It has only ever been run locally- thus, there are **no** built-in security features. Use at your own risk!

##Documentation
Not much here yet!